/*
 * Copyright 1992 by Jutta Degener and Carsten Bormann, Technische
 * Universitaet Berlin.  See the accompanying file "COPYRIGHT" for
 * details.  THERE IS ABSOLUTELY NO WARRANTY FOR THIS SOFTWARE.
 */

/*$Header: /sources/gnuradio/gr-gsm-fr-vocoder/src/lib/gsm/config.h,v 1.2 2006/04/16 01:37:04 eb Exp $*/

#ifndef	CONFIG_H
#define	CONFIG_H

#undef	SIGHANDLER_T	 		/* signal handlers are void	*/
#undef HAS_SYSV_SIGNAL			/* sigs not blocked/reset?	*/

#define	HAS_STDLIB_H	1		/* /usr/include/stdlib.h	*/
#undef	HAS_LIMITS_H			/* /usr/include/limits.h	*/
#define	HAS_FCNTL_H	1		/* /usr/include/fcntl.h		*/
#undef	HAS_ERRNO_DECL			/* errno.h declares errno	*/

#define	HAS_FSTAT 	1		/* fstat syscall		*/
#define	HAS_FCHMOD 	1		/* fchmod syscall		*/
#define	HAS_CHMOD 	1		/* chmod syscall		*/
#define	HAS_FCHOWN 	1		/* fchown syscall		*/
#define	HAS_CHOWN 	1		/* chown syscall		*/
#undef	HAS__FSETMODE 			/* _fsetmode -- set file mode	*/

#define	HAS_STRING_H 	1		/* /usr/include/string.h 	*/
#undef	HAS_STRINGS_H			/* /usr/include/strings.h 	*/

#define	HAS_UNISTD_H	1		/* /usr/include/unistd.h	*/
#define	HAS_UTIME	1		/* POSIX utime(path, times)	*/
#undef	HAS_UTIMES			/* use utimes()	syscall instead	*/
#define	HAS_UTIME_H	1		/* UTIME header file		*/
#undef	HAS_UTIMBUF			/* struct utimbuf		*/
#undef	HAS_UTIMEUSEC   		/* microseconds in utimbuf?	*/

#endif	/* CONFIG_H */
